<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=uk
// ** ne pas modifier le fichier **

return [

	// M
	'mediabox_description' => 'Зазвичай усі посилання на зображення (файли з відповідним mime/type атрибутом) і посилання з CSS класом <code>.mediabox</code> виводяться у вікні, що спливає.
	
	Ви можете налаштувати клас посилання для кожного випадку:

-* <code>boxIframe</code> дозволяє відкривати посилання в iframe ;

-* <code>boxWidth-350px</code> задає ширину спливаючого вікна у 350px ;

-* <code>boxHeight-90pc</code> задає висоту вікна у 90%.

В налаштуваннях модуля ви можете змінити зовнішній вигляд блоків та інші налаштування.
	Модуль працює лише в тому випадку, якщо ви додаєте тег <code>#INSERT_HEAD</code> до ваших шаблонів.',
	'mediabox_nom' => 'MediaBox',
	'mediabox_slogan' => 'Медіабокс',
];
